import os,time,glob
import numpy as np
import datetime as dt
import vtk
from vtk.util import numpy_support as VN

if __name__ == "__main__":
    start_time = time.time()
    ######################################################################
    # USER INPUTS
    ######################################################################
    path='localdbug/mothersday/'
    outpath = 'localdbug/mothersday/vtk/'
    ######################################################################

    #Make the paths if they don't already exist
    os.makedirs(outpath, exist_ok=True)

    filelist = glob.glob(path+'*vtk*.vtu')
    reader = vtk.vtkXMLUnstructuredGridReader()
    for infile in filelist[0:1]:
        print('processing '+infile.split('/')[-1]+'...')
        reader.SetFileName(infile)
        reader.Update()
        output = reader.GetOutput()
        point_data = output.GetPointData()
        bx = point_data.GetArray('B_x_nT')
        by = point_data.GetArray('B_y_nT')
        bz = point_data.GetArray('B_z_nT')

        Bx = VN.vtk_to_numpy(bx)
        By = VN.vtk_to_numpy(by)
        Bz = VN.vtk_to_numpy(bz)
        Bvect = np.array(list(zip(Bx,By,Bz)))

        bvect = VN.numpy_to_vtk(Bvect)
        arr_num = point_data.AddArray(bvect)
        B = point_data.GetArray(arr_num)
        B.SetName('B')
        '''
        import vtk
VFT = vtk.vtkVectorFieldTopology()
VFT.SetInputData(inputs[0].VTKObject)
VFT.SetOutput(output.VTKObject)
VFT.SetInputArrayToProcess(21,0,0,0,'B')
VFT.SetIntegrationStepUnit('Length')
VFT.SetExcludeBoundary(True)
VFT.SetOffsetAwayFromBoundary(3)
VFT.SetComputeSurfaces(True)
VFT.Update()
result = VFT.GetOutput()


        '''

        vft = vtk.vtkVectorFieldTopology()
        from IPython import embed; embed()
        '''
        aux = read_aux(infile.replace('.plt','.aux'))
        oldsource,pipelinehead,field,mp=setup_pipeline(infile,aux=aux,
                                                       doEnergy=False)
        ###Surface flux on magnetopause
        get_surface_flux(mp, 'B_nT','Bnormal_net')
        mp_Bnorm = FindSource('Bnormal_net')
        #decide which values to calculate (will need to make cell data)
        #fluxes = [('K_W_Re2','k_flux'),('P0_W_Re2','h_flux'),
        #          ('ExB_W_Re2','p_flux')]
        #mp_cc = point2cell(mp,fluxes)#mp object with cell centered data
        #mp_K_flux = get_surface_flux(mp, 'K_W_Re2','k_flux')
        #mp_S_flux = get_surface_flux(mp_cc, 'ExB_W_Re2','s_net_flux')
        renderView1 = GetActiveViewOrCreate('RenderView')
        #TODO find how to limit integration variables and group all together
        #tableLayout, tableView = setup_table()
        #save_table_data(mp_S_flux, tableView, outpath,'s_net_flux')
        SetActiveView(renderView1)
        pv_visuals.display_visuals(field,mp,renderView1,
                        mpContourBy='B_x_nT',contourMin=-10,contourMax=10,
                        **kwargs)

        # Create a new 'Render View'
        layout = GetLayout()
        layout.SplitVertical(0, 0.5)
        renderView2 = CreateView('RenderView')
        # assign view to a particular cell in the layout
        AssignViewToLayout(view=renderView2, layout=layout, hint=2)
        display_visuals(field,mp_Bnorm,renderView2,doSlice=True,
                        mpContourBy='Bnormal_net',
                        contourMin=-10,contourMax=10,
                        cmap='Cool to Warm')

        # Render and save screenshot
        RenderAllViews()
        # layout/tab size in pixels
        layout.SetSize(2162, 1079)
        SaveScreenshot(outpath+
                       infile.split('/')[-1].split('.plt')[0]+'.png',layout,
                       SaveAllViews=1,ImageResolution=[2162,1079])
    for infile in filelist[0:-1]:
        print('processing '+infile.split('/')[-1]+'...')
        outfile=outpath+infile.split('/')[-1].split('.plt')[0]+'.png'
        if os.path.exists(outfile):
            print(outfile+' already exists, skipping')
        else:
            #Read in new file unattached to current pipeline
            SetActiveSource(None)
            newsource = read_tecplot(infile)

            #Attach pipeline to the new source file and delete the old
            pipelinehead.Input = newsource
            Delete(oldsource)

            # Render and save screenshot
            RenderAllViews()
            # layout/tab size in pixels
            layout.SetSize(2162, 1079)
            SaveScreenshot(outpath+
                        infile.split('/')[-1].split('.plt')[0]+'.png',layout,
                        SaveAllViews=1,ImageResolution=[2162,1079])

            # Set the current source to be replaced on next loop
            oldsource = newsource
        '''
    #timestamp
    ltime = time.time()-start_time
    print('DONE')
    print('--- {:d}min {:.2f}s ---'.format(int(ltime/60),
                                           np.mod(ltime,60)))
